.. erado documentation master file, created by
   sphinx-quickstart on Wed Mar  4 15:38:45 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:
   :maxdepth: 2

   self
   getting-started
   CONTRIBUTING
   api/index
   lic-page
   genindex
